@@ -37,7 +37,7 @@ def verify_branch() -> None:
     if "On branch master" in str(out):
 
         echo(
-            f"We don't use master branches any longer {angered_face}\n"
+            f"You are on the master branch but we agreed to only use main... {angered_face}\n"
             f"Please rename the branch, darling {face_blowing_kiss}"
         )
         sys.exit()
